---
title: Guide
weight: 2
prev: /docs/getting-started
next: /docs/guide/organize-files
sidebar:
  open: true
---

Explore the following sections to learn how to use Hextra:

<!--more-->

{{< cards >}}
  {{< card link="organize-files" title="Organize Files" icon="document-duplicate" >}}
  {{< card link="configuration" title="Configuration" icon="adjustments" >}}
  {{< card link="markdown" title="Markdown" icon="markdown" >}}
  {{< card link="syntax-highlighting" title="Syntax Highlighting" icon="sparkles" >}}
  {{< card link="latex" title="LaTeX" icon="variable" >}}
  {{< card link="diagrams" title="Diagrams" icon="chart-square-bar" >}}
  {{< card link="shortcodes" title="Shortcodes" icon="template" >}}
  {{< card link="deploy-site" title="Deploy Site" icon="server" >}}
{{< /cards >}}
